#!/usr/bin/env python3
            
# -*- coding: utf-8 -*-

'''
.. module:: alpacaz
   :platform: Unix, Windows
   :synopsis: This is the main module for alpacaz.

.. moduleauthor:: Lalith Kumar Shiyam Sundar, Zacharias Chalampalakis <Lalith.shiyamsundar@meduniwien.ac.at>

'''

# Your code here
